@@ -41,7 +41,6 @@
 #include "ephy-snapshot-service.h"
 #include "ephy-tabs-catalog.h"
 #include "ephy-uri-helpers.h"
-#include "ephy-uri-tester-shared.h"
 #include "ephy-view-source-handler.h"
 #include "ephy-web-app-utils.h"
 #include "ephy-web-process-extension-proxy.h"
@@ -113,7 +112,7 @@ ephy_embed_shell_get_view_for_page_id (EphyEmbedShell *self,
   GList *windows = gtk_application_get_windows (GTK_APPLICATION (self));
 
   for (GList *l = windows; l && l->data; l = l->next) {
-    g_autoptr(GList) tabs = ephy_embed_container_get_children (l->data);
+    g_autoptr (GList) tabs = ephy_embed_container_get_children (l->data);
 
     for (GList *t = tabs; t && t->data; t = t->next) {
       EphyWebView *ephy_view = ephy_embed_get_web_view (t->data);
@@ -152,7 +151,7 @@ tabs_catalog_get_tabs_info (EphyTabsCatalog *catalog)
   EphyEmbedShell *embed_shell = EPHY_EMBED_SHELL (catalog);
   WebKitFaviconDatabase *database;
   GList *windows;
-  g_autoptr(GList) tabs = NULL;
+  g_autoptr (GList) tabs = NULL;
   GList *tabs_info = NULL;
   const char *title;
   const char *url;
@@ -229,7 +228,7 @@ web_process_extension_password_form_focused_message_received_cb (WebKitUserConte
 {
   guint64 page_id;
   gboolean insecure_action;
-  g_autoptr(GVariant) variant = NULL;
+  g_autoptr (GVariant) variant = NULL;
   g_autofree char *message_str = NULL;
 
   message_str = jsc_value_to_string (webkit_javascript_result_get_js_value (message));
@@ -266,7 +265,7 @@ static void
 ephy_embed_shell_update_overview_urls (EphyEmbedShell *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-  g_autoptr(EphyHistoryQuery) query = NULL;
+  g_autoptr (EphyHistoryQuery) query = NULL;
 
   query = ephy_history_query_new_for_overview ();
   ephy_history_service_query_urls (priv->global_history_service, query, NULL,
@@ -374,8 +373,8 @@ password_manager_query_finished_cb (GList               *records,
   }
 
   proxy = ephy_embed_shell_get_extension_proxy_for_page_id (data->shell,
-                                                                                   data->page_id,
-                                                                                   data->origin);
+                                                            data->page_id,
+                                                            data->origin);
   if (proxy)
     ephy_web_process_extension_proxy_password_query_response (proxy, username, password, data->promise_id, data->frame_id);
 
@@ -386,7 +385,7 @@ static char *
 property_to_string_or_null (JSCValue   *value,
                             const char *name)
 {
-  g_autoptr(JSCValue) prop = jsc_value_object_get_property (value, name);
+  g_autoptr (JSCValue) prop = jsc_value_object_get_property (value, name);
   if (jsc_value_is_null (prop) || jsc_value_is_undefined (prop))
     return NULL;
   return jsc_value_to_string (prop);
@@ -396,7 +395,7 @@ static int
 property_to_int32 (JSCValue   *value,
                    const char *name)
 {
-  g_autoptr(JSCValue) prop = jsc_value_object_get_property (value, name);
+  g_autoptr (JSCValue) prop = jsc_value_object_get_property (value, name);
   return jsc_value_to_int32 (prop);
 }
 
@@ -404,7 +403,7 @@ static int
 property_to_uint64 (JSCValue   *value,
                     const char *name)
 {
-  g_autoptr(JSCValue) prop = jsc_value_object_get_property (value, name);
+  g_autoptr (JSCValue) prop = jsc_value_object_get_property (value, name);
   return (guint64)jsc_value_to_double (prop);
 }
 
@@ -480,8 +479,8 @@ save_auth_request_free (SaveAuthRequest *request)
 }
 
 static void
-save_auth_request_response_cb (gint                 response_id,
-                               SaveAuthRequest      *data)
+save_auth_request_response_cb (gint             response_id,
+                               SaveAuthRequest *data)
 {
   if (response_id == GTK_RESPONSE_REJECT) {
     ephy_permissions_manager_set_permission (data->permissions_manager,
@@ -507,7 +506,7 @@ web_process_extension_password_manager_save_real (EphyEmbedShell *shell,
   g_autofree char *password = property_to_string_or_null (value, "password");
   g_autofree char *username_field = property_to_string_or_null (value, "usernameField");
   g_autofree char *password_field = property_to_string_or_null (value, "passwordField");
-  g_autoptr(JSCValue) is_new_prop = jsc_value_object_get_property (value, "isNew");
+  g_autoptr (JSCValue) is_new_prop = jsc_value_object_get_property (value, "isNew");
   gboolean is_new = jsc_value_to_boolean (is_new_prop);
   guint64 page_id = property_to_uint64 (value, "pageID");
   EphyWebView *view;
@@ -641,7 +640,7 @@ history_service_host_deleted_cb (EphyHistoryService *service,
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
   GList *l;
-  g_autoptr(SoupURI) deleted_uri = NULL;
+  g_autoptr (SoupURI) deleted_uri = NULL;
 
   deleted_uri = soup_uri_new (deleted_url);
 
@@ -738,7 +737,7 @@ got_snapshot_path_for_url_cb (EphySnapshotService *service,
                               char                *url)
 {
   g_autofree char *snapshot = NULL;
-  g_autoptr(GError) error = NULL;
+  g_autoptr (GError) error = NULL;
 
   snapshot = ephy_snapshot_service_get_snapshot_path_for_url_finish (service, result, &error);
   if (snapshot) {
@@ -892,8 +891,8 @@ ephy_resource_request_cb (WebKitURISchemeRequest *request)
 {
   const char *path;
   gsize size;
-  g_autoptr(GInputStream) stream = NULL;
-  g_autoptr(GError) error = NULL;
+  g_autoptr (GInputStream) stream = NULL;
+  g_autoptr (GError) error = NULL;
 
   path = webkit_uri_scheme_request_get_path (request);
   if (!g_resources_get_info (path, 0, &size, NULL, &error)) {
@@ -911,9 +910,9 @@ ephy_resource_request_cb (WebKitURISchemeRequest *request)
 static void
 ftp_request_cb (WebKitURISchemeRequest *request)
 {
-  g_autoptr(GDesktopAppInfo) app_info = NULL;
-  g_autoptr(GList) list = NULL;
-  g_autoptr(GError) error = NULL;
+  g_autoptr (GDesktopAppInfo) app_info = NULL;
+  g_autoptr (GList) list = NULL;
+  g_autoptr (GError) error = NULL;
   const char *uri;
 
   uri = webkit_uri_scheme_request_get_uri (request);
@@ -939,7 +938,7 @@ initialize_web_process_extensions (WebKitWebContext *web_context,
                                    EphyEmbedShell   *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-  g_autoptr(GVariant) user_data = NULL;
+  g_autoptr (GVariant) user_data = NULL;
   gboolean private_profile;
   gboolean browser_mode;
   const char *address;
@@ -954,11 +953,10 @@ initialize_web_process_extensions (WebKitWebContext *web_context,
 
   private_profile = priv->mode == EPHY_EMBED_SHELL_MODE_PRIVATE || priv->mode == EPHY_EMBED_SHELL_MODE_INCOGNITO || priv->mode == EPHY_EMBED_SHELL_MODE_AUTOMATION;
   browser_mode = priv->mode == EPHY_EMBED_SHELL_MODE_BROWSER;
-  user_data = g_variant_new ("(smsmssbb)",
+  user_data = g_variant_new ("(smsmsbb)",
                              priv->guid,
                              address,
                              ephy_profile_dir_is_default () ? NULL : ephy_profile_dir (),
-                             ephy_filters_manager_get_adblock_filters_dir (priv->filters_manager),
                              private_profile,
                              browser_mode);
   webkit_web_context_set_web_extensions_initialization_user_data (web_context, g_steal_pointer (&user_data));
@@ -1004,7 +1002,7 @@ new_connection_cb (GDBusServer     *server,
                    EphyEmbedShell  *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-  g_autoptr(EphyWebProcessExtensionProxy) extension = NULL;
+  g_autoptr (EphyWebProcessExtensionProxy) extension = NULL;
 
   extension = ephy_web_process_extension_proxy_new (connection);
 
@@ -1031,11 +1029,15 @@ static void
 ephy_embed_shell_setup_web_process_extensions_server (EphyEmbedShell *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-  g_autoptr(GDBusAuthObserver) observer = NULL;
+  g_autoptr (GDBusAuthObserver) observer = NULL;
   g_autofree char *address = NULL;
-  g_autoptr(GError) error = NULL;
+  g_autoptr (GError) error = NULL;
 
-  address = g_strdup_printf ("unix:tmpdir=%s", g_get_tmp_dir ());
+  /* Due to the bubblewrap sandbox, we cannot use any abstract sockets here.
+   * This means that unix:tmpdir= or unix:abstract= addresses will not work.
+   * Using unix:dir= guarantees that abstract sockets won't be used.
+   */
+  address = g_strdup_printf ("unix:dir=%s", ephy_file_tmp_dir ());
 
   observer = g_dbus_auth_observer_new ();
 
@@ -1055,7 +1057,7 @@ ephy_embed_shell_setup_web_process_extensions_server (EphyEmbedShell *shell)
                                               &error);
 
   if (error) {
-    g_warning ("Failed to start web process extension server on %s: %s", address, error->message);
+    g_warning ("Failed to start embed shell D-Bus server on %s: %s", address, error->message);
     return;
   }
 
@@ -1068,7 +1070,7 @@ static void
 ephy_embed_shell_create_web_context (EphyEmbedShell *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-  g_autoptr(WebKitWebsiteDataManager) manager = NULL;
+  g_autoptr (WebKitWebsiteDataManager) manager = NULL;
 
   if (priv->mode == EPHY_EMBED_SHELL_MODE_INCOGNITO) {
     priv->web_context = webkit_web_context_new_ephemeral ();
@@ -1088,19 +1090,13 @@ ephy_embed_shell_create_web_context (EphyEmbedShell *shell)
   priv->web_context = webkit_web_context_new_with_website_data_manager (manager);
 }
 
-static char *
-adblock_filters_dir (EphyEmbedShell *shell)
-{
-  return g_build_filename (ephy_cache_dir (), "adblock", NULL);
-}
-
 static void
 download_started_cb (WebKitWebContext *web_context,
                      WebKitDownload   *download,
                      EphyEmbedShell   *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-  g_autoptr(EphyDownload) ephy_download = NULL;
+  g_autoptr (EphyDownload) ephy_download = NULL;
   gboolean ephy_download_set;
 
   /* Is download locked down? */
@@ -1179,33 +1175,43 @@ ephy_embed_shell_startup (GApplication *application)
   webkit_user_content_manager_register_script_message_handler_in_world (priv->user_content,
                                                                         "passwordManagerQuery",
                                                                         priv->guid);
-  g_signal_connect (priv->user_content, "script-message-received::passwordManagerQuery",
-                    G_CALLBACK (web_process_extension_password_manager_query_received_cb),
-                    shell);
+  g_signal_connect_object (priv->user_content, "script-message-received::passwordManagerQuery",
+                           G_CALLBACK (web_process_extension_password_manager_query_received_cb),
+                           shell, 0);
 
   webkit_user_content_manager_register_script_message_handler_in_world (priv->user_content,
                                                                         "passwordManagerQueryUsernames",
                                                                         priv->guid);
-  g_signal_connect (priv->user_content, "script-message-received::passwordManagerQueryUsernames",
-                    G_CALLBACK (web_process_extension_password_manager_query_usernames_received_cb),
-                    shell);
+  g_signal_connect_object (priv->user_content, "script-message-received::passwordManagerQueryUsernames",
+                           G_CALLBACK (web_process_extension_password_manager_query_usernames_received_cb),
+                           shell, 0);
 
   webkit_user_content_manager_register_script_message_handler_in_world (priv->user_content,
                                                                         "passwordManagerSave",
                                                                         priv->guid);
-  g_signal_connect (priv->user_content, "script-message-received::passwordManagerSave",
-                    G_CALLBACK (web_process_extension_password_manager_save_received_cb),
-                    shell);
+  g_signal_connect_object (priv->user_content, "script-message-received::passwordManagerSave",
+                           G_CALLBACK (web_process_extension_password_manager_save_received_cb),
+                           shell, 0);
 
   webkit_user_content_manager_register_script_message_handler_in_world (priv->user_content,
                                                                         "passwordManagerRequestSave",
                                                                         priv->guid);
-  g_signal_connect (priv->user_content, "script-message-received::passwordManagerRequestSave",
-                    G_CALLBACK (web_process_extension_password_manager_request_save_received_cb),
-                    shell);
+  g_signal_connect_object (priv->user_content, "script-message-received::passwordManagerRequestSave",
+                           G_CALLBACK (web_process_extension_password_manager_request_save_received_cb),
+                           shell, 0);
 
   webkit_web_context_set_process_model (priv->web_context, WEBKIT_PROCESS_MODEL_MULTIPLE_SECONDARY_PROCESSES);
 
+  webkit_web_context_set_sandbox_enabled (priv->web_context, TRUE);
+  webkit_web_context_add_path_to_sandbox (priv->web_context, ephy_file_tmp_dir (), TRUE);
+  webkit_web_context_add_path_to_sandbox (priv->web_context, ephy_profile_dir (), TRUE);
+  webkit_web_context_add_path_to_sandbox (priv->web_context, ephy_cache_dir (), TRUE);
+  webkit_web_context_add_path_to_sandbox (priv->web_context, ephy_config_dir (), TRUE);
+
+#if DEVELOPER_MODE
+  webkit_web_context_add_path_to_sandbox (priv->web_context, BUILD_ROOT, TRUE);
+#endif
+
   g_signal_connect_object (priv->web_context, "initialize-web-extensions",
                            G_CALLBACK (initialize_web_process_extensions),
                            shell, 0);
@@ -1268,11 +1274,20 @@ ephy_embed_shell_startup (GApplication *application)
                                          EPHY_PREFS_WEB_COOKIES_POLICY);
   ephy_embed_prefs_set_cookie_accept_policy (cookie_manager, cookie_policy);
 
-  filters_dir = adblock_filters_dir (shell);
+  filters_dir = g_build_filename (ephy_cache_dir (), "adblock", NULL);
   priv->filters_manager = ephy_filters_manager_new (filters_dir);
 
-  g_signal_connect (priv->web_context, "download-started",
-                    G_CALLBACK (download_started_cb), shell);
+  g_signal_connect_object (priv->filters_manager, "filters-disabled",
+                           G_CALLBACK (webkit_user_content_manager_remove_all_filters),
+                           priv->user_content,
+                           G_CONNECT_SWAPPED);
+  g_signal_connect_object (priv->filters_manager, "filter-ready",
+                           G_CALLBACK (webkit_user_content_manager_add_filter),
+                           priv->user_content,
+                           G_CONNECT_SWAPPED);
+
+  g_signal_connect_object (priv->web_context, "download-started",
+                           G_CALLBACK (download_started_cb), shell, 0);
 }
 
 static void
@@ -1362,7 +1377,7 @@ ephy_embed_shell_constructed (GObject *object)
   mode = ephy_embed_shell_get_mode (shell);
 
   /* These do not run the EmbedShell application instance, so make sure that
-     there is a web context and a user content manager for them. */
+   *  there is a web context and a user content manager for them. */
   if (mode == EPHY_EMBED_SHELL_MODE_TEST ||
       mode == EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER) {
     ephy_embed_shell_create_web_context (shell);
