@@ -29,7 +29,6 @@
 #include "ephy-prefs.h"
 #include "ephy-settings.h"
 #include "ephy-uri-helpers.h"
-#include "ephy-uri-tester.h"
 #include "ephy-web-overview-model.h"
 
 #include <gio/gio.h>
@@ -53,7 +52,6 @@ struct _EphyWebProcessExtension {
 
   EphyWebOverviewModel *overview_model;
   EphyPermissionsManager *permissions_manager;
-  EphyUriTester *uri_tester;
 
   WebKitScriptWorld *script_world;
 
@@ -102,116 +100,20 @@ static const char introspection_xml[] =
 
 G_DEFINE_TYPE (EphyWebProcessExtension, ephy_web_process_extension, G_TYPE_OBJECT)
 
-static void
-log_to_js_console (EphyWebProcessExtension *extension,
-                   WebKitWebPage           *page,
-                   const char              *str,
-                   ...)
-{
-  g_autoptr(JSCContext) js_context = NULL;
-  g_autoptr(JSCValue) js_console = NULL;
-  g_autoptr(JSCValue) js_result = NULL;
-  g_autofree char *expanded_str = NULL;
-  WebKitFrame *frame;
-  va_list args;
-  int ret;
-
-  va_start (args, str);
-  ret = g_vasprintf (&expanded_str, str, args);
-  g_assert (ret > 0);
-  va_end (args);
-
-  frame = webkit_web_page_get_main_frame (page);
-  js_context = webkit_frame_get_js_context_for_script_world (frame, extension->script_world);
-  js_console = jsc_context_get_value (js_context, "console");
-  js_result = jsc_value_object_invoke_method (js_console,
-                                              "log",
-                                              G_TYPE_STRING, expanded_str,
-                                              G_TYPE_NONE);
-}
-
 static gboolean
-should_use_adblocker (const char              *request_uri,
-                      const char              *page_uri,
-                      const char              *redirected_request_uri,
-                      EphyWebProcessExtension *extension)
+web_page_send_request (WebKitWebPage           *web_page,
+                       WebKitURIRequest        *request,
+                       WebKitURIResponse       *redirected_response,
+                       EphyWebProcessExtension *extension)
 {
-  g_autofree gchar *origin = ephy_uri_to_security_origin (page_uri);
-  EphyPermission permission = EPHY_PERMISSION_UNDECIDED;
-
-  /* Check page setting first in case it overwrites global setting */
-  if (origin) {
-    permission = ephy_permissions_manager_get_permission (extension->permissions_manager,
-                                                          EPHY_PERMISSION_TYPE_SHOW_ADS,
-                                                          origin);
-    if (permission == EPHY_PERMISSION_PERMIT)
-      return FALSE;
-  }
-
-  if (permission == EPHY_PERMISSION_UNDECIDED && !g_settings_get_boolean (EPHY_SETTINGS_WEB_PROCESS_EXTENSION_WEB, EPHY_PREFS_WEB_ENABLE_ADBLOCK))
-    return FALSE;
-
-  /* Always load the main resource... */
-  if (g_strcmp0 (request_uri, page_uri) == 0)
-    return FALSE;
-
-  /* ...even during a redirect, when page_uri is stale. */
-  if (g_strcmp0 (page_uri, redirected_request_uri) == 0)
-    return FALSE;
-
-  /* Always load data requests, as uri_tester won't do any good here. */
-  if (g_str_has_prefix (request_uri, SOUP_URI_SCHEME_DATA))
-    return FALSE;
-
-  /* Always load about pages */
-  if (g_str_has_prefix (request_uri, "about") ||
-      g_str_has_prefix (request_uri, "ephy-about"))
-    return FALSE;
-
-  /* Always load resources */
-  if (g_str_has_prefix (request_uri, "resource://") ||
-      g_str_has_prefix (request_uri, "ephy-resource://"))
-    return FALSE;
-
-  /* Always load local files */
-  if (g_str_has_prefix (request_uri, "file://"))
-    return FALSE;
-
-  return TRUE;
-}
-
-static gboolean
-web_page_send_request (WebKitWebPage            *web_page,
-                       WebKitURIRequest         *request,
-                       WebKitURIResponse        *redirected_response,
-                       EphyWebProcessExtension  *extension)
-{
-  const char *request_uri;
-  const char *redirected_response_uri;
-  const char *page_uri;
-  g_autofree char *modified_uri = NULL;
-
-  request_uri = webkit_uri_request_get_uri (request);
-  page_uri = webkit_web_page_get_uri (web_page);
-  redirected_response_uri = redirected_response ? webkit_uri_response_get_uri (redirected_response) : NULL;
-
-  if (g_settings_get_boolean (EPHY_SETTINGS_WEB_PROCESS_EXTENSION_WEB, EPHY_PREFS_WEB_DO_NOT_TRACK))
-    modified_uri = ephy_remove_tracking_from_uri (request_uri);
-
-  if (should_use_adblocker (request_uri, page_uri, redirected_response_uri, extension)) {
-    gboolean result;
-
-    ephy_uri_tester_load (extension->uri_tester);
-    result = ephy_uri_tester_is_uri_allowed (extension->uri_tester,
-                                             modified_uri ? modified_uri : request_uri,
-                                             page_uri);
-    if (!result) {
-      LOG ("Adblocker refused to load %s", request_uri);
-      log_to_js_console (extension, web_page, _("Epiphany adblocker refused to load %s"), request_uri);
-      return TRUE;
+  if (g_settings_get_boolean (EPHY_SETTINGS_WEB_PROCESS_EXTENSION_WEB, EPHY_PREFS_WEB_DO_NOT_TRACK)) {
+    const char *request_uri = webkit_uri_request_get_uri (request);
+    g_autofree char *modified_uri = ephy_remove_tracking_from_uri (request_uri);
+    if (modified_uri && g_strcmp0 (request_uri, modified_uri) != 0) {
+      LOG ("Rewrote %s to %s", request_uri, modified_uri);
+      webkit_uri_request_set_uri (request, modified_uri);
     }
   }
-
   return FALSE;
 }
 
@@ -226,10 +128,10 @@ web_page_will_submit_form (WebKitWebPage            *web_page,
 {
   EphyWebProcessExtension *extension;
   gboolean form_submit_handled;
-  g_autoptr(JSCContext) js_context = NULL;
-  g_autoptr(JSCValue) js_ephy = NULL;
-  g_autoptr(JSCValue) js_form = NULL;
-  g_autoptr(JSCValue) js_result = NULL;
+  g_autoptr (JSCContext) js_context = NULL;
+  g_autoptr (JSCValue) js_ephy = NULL;
+  g_autoptr (JSCValue) js_form = NULL;
+  g_autoptr (JSCValue) js_result = NULL;
 
   form_submit_handled =
     GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dom_form),
@@ -294,11 +196,11 @@ web_page_form_controls_associated (WebKitWebPage           *web_page,
                                    WebKitFrame             *frame,
                                    EphyWebProcessExtension *extension)
 {
-  g_autoptr(GPtrArray) form_controls = NULL;
-  g_autoptr(JSCContext) js_context = NULL;
-  g_autoptr(JSCValue) js_ephy = NULL;
-  g_autoptr(JSCValue) js_serializer = NULL;
-  g_autoptr(JSCValue) js_result = NULL;
+  g_autoptr (GPtrArray) form_controls = NULL;
+  g_autoptr (JSCContext) js_context = NULL;
+  g_autoptr (JSCValue) js_ephy = NULL;
+  g_autoptr (JSCValue) js_serializer = NULL;
+  g_autoptr (JSCValue) js_result = NULL;
   guint i;
 
   js_context = webkit_frame_get_js_context_for_script_world (frame, extension->script_world);
@@ -340,8 +242,8 @@ web_page_context_menu (WebKitWebPage          *web_page,
   g_autofree char *string = NULL;
   GVariantBuilder builder;
   WebKitFrame *frame;
-  g_autoptr(JSCContext) js_context = NULL;
-  g_autoptr(JSCValue) js_value = NULL;
+  g_autoptr (JSCContext) js_context = NULL;
+  g_autoptr (JSCValue) js_value = NULL;
 
   extension = ephy_web_process_extension_get ();
   /* FIXME: this is wrong, see https://gitlab.gnome.org/GNOME/epiphany/issues/442
@@ -369,7 +271,7 @@ static void
 ephy_web_process_extension_emit_page_created (EphyWebProcessExtension *extension,
                                               guint64                  page_id)
 {
-  g_autoptr(GError) error = NULL;
+  g_autoptr (GError) error = NULL;
 
   g_dbus_connection_emit_signal (extension->dbus_connection,
                                  NULL,
@@ -415,7 +317,7 @@ ephy_web_process_extension_page_created_cb (EphyWebProcessExtension *extension,
                                             WebKitWebPage           *web_page)
 {
   guint64 page_id;
-  g_autoptr(JSCContext) js_context = NULL;
+  g_autoptr (JSCContext) js_context = NULL;
 
   /* Enforce the creation of the script world global context in the main frame */
   js_context = webkit_frame_get_js_context_for_script_world (webkit_web_page_get_main_frame (web_page), extension->script_world);
@@ -445,8 +347,8 @@ get_password_manager (EphyWebProcessExtension *self,
                       guint64                  frame_id)
 {
   WebKitFrame *frame;
-  g_autoptr(JSCContext) js_context = NULL;
-  g_autoptr(JSCValue) js_ephy = NULL;
+  g_autoptr (JSCContext) js_context = NULL;
+  g_autoptr (JSCValue) js_ephy = NULL;
 
   frame = g_hash_table_lookup (self->frames_map, GINT_TO_POINTER (frame_id));
   if (!frame)
@@ -476,7 +378,7 @@ handle_method_call (GDBusConnection       *connection,
   if (g_strcmp0 (method_name, "HistorySetURLs") == 0) {
     if (extension->overview_model) {
       GVariantIter iter;
-      g_autoptr(GVariant) array = NULL;
+      g_autoptr (GVariant) array = NULL;
       const char *url;
       const char *title;
       GList *items = NULL;
@@ -530,8 +432,8 @@ handle_method_call (GDBusConnection       *connection,
     g_dbus_method_invocation_return_value (invocation, NULL);
   } else if (g_strcmp0 (method_name, "PasswordQueryUsernamesResponse") == 0) {
     g_autofree const char **users;
-    g_autoptr(JSCValue) ret = NULL;
-    g_autoptr(JSCValue) password_manager = NULL;
+    g_autoptr (JSCValue) ret = NULL;
+    g_autoptr (JSCValue) password_manager = NULL;
     gint32 promise_id;
     guint64 frame_id;
 
@@ -548,8 +450,8 @@ handle_method_call (GDBusConnection       *connection,
     const char *password;
     gint32 promise_id;
     guint64 frame_id;
-    g_autoptr(JSCValue) ret = NULL;
-    g_autoptr(JSCValue) password_manager = NULL;
+    g_autoptr (JSCValue) ret = NULL;
+    g_autoptr (JSCValue) password_manager = NULL;
 
     g_variant_get (parameters, "(&s&sit)", &username, &password, &promise_id, &frame_id);
     password_manager = get_password_manager (extension, frame_id);
@@ -568,7 +470,9 @@ static const GDBusInterfaceVTable interface_vtable = {
 };
 
 static void
-drop_frame_weak_ref (gpointer key, gpointer value, gpointer extension)
+drop_frame_weak_ref (gpointer key,
+                     gpointer value,
+                     gpointer extension)
 {
   g_object_weak_unref (G_OBJECT (value), (GWeakNotify)frame_destroyed_notify, extension);
 }
@@ -578,7 +482,6 @@ ephy_web_process_extension_dispose (GObject *object)
 {
   EphyWebProcessExtension *extension = EPHY_WEB_PROCESS_EXTENSION (object);
 
-  g_clear_object (&extension->uri_tester);
   g_clear_object (&extension->overview_model);
   g_clear_object (&extension->permissions_manager);
 
@@ -632,9 +535,9 @@ dbus_connection_created_cb (GObject                 *source_object,
                             EphyWebProcessExtension *extension)
 {
   static GDBusNodeInfo *introspection_data = NULL;
-  g_autoptr(GDBusConnection) connection = NULL;
+  g_autoptr (GDBusConnection) connection = NULL;
   guint registration_id;
-  g_autoptr(GError) error = NULL;
+  g_autoptr (GError) error = NULL;
 
   if (!introspection_data)
     introspection_data = g_dbus_node_info_new_for_xml (introspection_xml, NULL);
@@ -723,8 +626,8 @@ static void
 js_exception_handler (JSCContext   *context,
                       JSCException *exception)
 {
-  g_autoptr(JSCValue) js_console = NULL;
-  g_autoptr(JSCValue) js_result = NULL;
+  g_autoptr (JSCValue) js_console = NULL;
+  g_autoptr (JSCValue) js_result = NULL;
   g_autofree char *report = NULL;
 
   js_console = jsc_context_get_value (context, "console");
@@ -736,18 +639,18 @@ js_exception_handler (JSCContext   *context,
 }
 
 static void
-window_object_cleared_cb (WebKitScriptWorld        *world,
-                          WebKitWebPage            *page,
-                          WebKitFrame              *frame,
-                          EphyWebProcessExtension  *extension)
+window_object_cleared_cb (WebKitScriptWorld       *world,
+                          WebKitWebPage           *page,
+                          WebKitFrame             *frame,
+                          EphyWebProcessExtension *extension)
 {
-  g_autoptr(JSCContext) js_context = NULL;
-  g_autoptr(GBytes) bytes = NULL;
-  const char* data;
+  g_autoptr (JSCContext) js_context = NULL;
+  g_autoptr (GBytes) bytes = NULL;
+  const char *data;
   gsize data_size;
-  g_autoptr(JSCValue) js_ephy = NULL;
-  g_autoptr(JSCValue) js_function = NULL;
-  g_autoptr(JSCValue) result = NULL;
+  g_autoptr (JSCValue) js_ephy = NULL;
+  g_autoptr (JSCValue) js_function = NULL;
+  g_autoptr (JSCValue) result = NULL;
 
   js_context = webkit_frame_get_js_context_for_script_world (frame, world);
   jsc_context_push_exception_handler (js_context, (JSCExceptionHandler)js_exception_handler, NULL, NULL);
@@ -777,9 +680,9 @@ window_object_cleared_cb (WebKitScriptWorld        *world,
   g_clear_object (&js_function);
 
   if (g_strcmp0 (webkit_web_page_get_uri (page), "ephy-about:overview") == 0) {
-    g_autoptr(JSCValue) js_overview = NULL;
-    g_autoptr(JSCValue) js_overview_ctor = NULL;
-    g_autoptr(JSCValue) jsc_overview_model = NULL;
+    g_autoptr (JSCValue) js_overview = NULL;
+    g_autoptr (JSCValue) js_overview_ctor = NULL;
+    g_autoptr (JSCValue) jsc_overview_model = NULL;
 
     bytes = g_resources_lookup_data ("/org/gnome/epiphany-web-process-extension/js/overview.js", G_RESOURCE_LOOKUP_FLAGS_NONE, NULL);
     data = g_bytes_get_data (bytes, &data_size);
@@ -802,11 +705,11 @@ window_object_cleared_cb (WebKitScriptWorld        *world,
                                                  js_ephy);
 
   if (!extension->is_private_profile) {
-    g_autoptr(JSCValue) js_password_manager_ctor = jsc_value_object_get_property (js_ephy, "PasswordManager");
-    g_autoptr(JSCValue) js_password_manager = jsc_value_constructor_call (js_password_manager_ctor,
-                                                                          G_TYPE_UINT64, webkit_web_page_get_id (page),
-                                                                          G_TYPE_UINT64, webkit_frame_get_id (frame),
-                                                                          G_TYPE_NONE);
+    g_autoptr (JSCValue) js_password_manager_ctor = jsc_value_object_get_property (js_ephy, "PasswordManager");
+    g_autoptr (JSCValue) js_password_manager = jsc_value_constructor_call (js_password_manager_ctor,
+                                                                           G_TYPE_UINT64, webkit_web_page_get_id (page),
+                                                                           G_TYPE_UINT64, webkit_frame_get_id (frame),
+                                                                           G_TYPE_NONE);
     jsc_value_object_set_property (js_ephy, "passwordManager", js_password_manager);
 
     js_function = jsc_value_new_function (js_context,
@@ -847,11 +750,10 @@ ephy_web_process_extension_initialize (EphyWebProcessExtension *extension,
                                        WebKitWebExtension      *wk_extension,
                                        const char              *guid,
                                        const char              *server_address,
-                                       const char              *adblock_data_dir,
                                        gboolean                 is_private_profile,
                                        gboolean                 is_browser_mode)
 {
-  g_autoptr(GDBusAuthObserver) observer = NULL;
+  g_autoptr (GDBusAuthObserver) observer = NULL;
 
   g_assert (EPHY_IS_WEB_PROCESS_EXTENSION (extension));
 
@@ -887,8 +789,6 @@ ephy_web_process_extension_initialize (EphyWebProcessExtension *extension,
                                      (GAsyncReadyCallback)dbus_connection_created_cb,
                                      extension);
 
-  extension->uri_tester = ephy_uri_tester_new (adblock_data_dir);
-
   extension->frames_map = g_hash_table_new_full (g_direct_hash, g_direct_equal,
                                                  NULL, NULL);
 }
