@@ -21,6 +21,7 @@
 #pragma once
 
 #include "ephy-bookmarks-manager.h"
+#include "ephy-embed.h"
 #include "ephy-embed-event.h"
 #include "ephy-location-controller.h"
 #include "ephy-web-view.h"
@@ -46,6 +47,7 @@ typedef enum
 EphyWindow       *ephy_window_new                 (void);
 
 GtkWidget        *ephy_window_get_notebook        (EphyWindow *window);
+GtkWidget        *ephy_window_get_stack           (EphyWindow *window);
 
 void              ephy_window_load_url            (EphyWindow *window,
                                                    const char *url);
@@ -79,4 +81,7 @@ void              ephy_window_set_default_position     (EphyWindow *window,
                                                         gint        y);
 void              ephy_window_show_fullscreen_header_bar (EphyWindow *window);
 
+int               ephy_window_get_position_for_new_embed (EphyWindow *window,
+                                                          EphyEmbed  *embed);
+
 G_END_DECLS
